Run the Percentile Climate-Smart Approach
Source:R/utils-climate.R
splnr_climate_percentileApproach.Rdsplnr_climate_percentileApproach() implements the Percentile Approach to
climate-smart conservation planning by filtering features to their most
climate-resilient areas and adjusting targets accordingly.
Usage
splnr_climate_percentileApproach(
features,
metric,
targets,
direction,
percentile = 35,
metric_col = "metric"
)Arguments
- features
An
sfobject of conservation features.- metric
An
sfobject with a column namedmetric.- targets
A
data.framewith columnsfeatureandtarget.- direction
1or-1.- percentile
Numeric (0-100). Defaults to
35.- metric_col
A single character string giving the name of the column in
metricthat contains the climate metric values. Defaults to"metric"for backwards compatibility. Use this argument when your climate data column has a different name (e.g."sst_trend").
Value
A list with:
Features:sfobject filtered to climate-smart occurrences.Targets:data.framewith adjusted targets.
Details
This function orchestrates two steps:
Preprocessing via
splnr_climate_percentile_preprocess().Target Assignment via
splnr_climate_percentile_assignTargets().
Examples
if (FALSE) { # \dontrun{
initial_targets <- dat_species_bin %>%
sf::st_drop_geometry() %>%
colnames() %>%
data.frame() %>%
setNames(c("feature")) %>%
dplyr::mutate(target = 0.3)
Percentile_result <- splnr_climate_percentileApproach(
features = dat_species_bin,
metric = dat_clim,
targets = initial_targets,
direction = 1,
percentile = 35
)
out_sf_percentile <- Percentile_result$Features
targets_percentile <- Percentile_result$Targets
} # }